/// <reference types="node" />
export declare type FfiPactHandle = number;
export declare type FfiInteractionHandle = number;
export declare type FfiSpecificationVersion = 0 | 1 | 2 | 3 | 4 | 5;
export declare const FfiSpecificationVersion: Record<string, FfiSpecificationVersion>;
export declare type FfiWritePactResponse = 0 | 1 | 2 | 3;
export declare const FfiWritePactResponse: Record<string, FfiWritePactResponse>;
export declare type FfiInteractionPart = 0 | 1;
export declare const INTERACTION_PART_REQUEST: FfiInteractionPart;
export declare const INTERACTION_PART_RESPONSE: FfiInteractionPart;
export declare const CREATE_MOCK_SERVER_ERRORS: {
    NULL_POINTER: number;
    JSON_PARSE_ERROR: number;
    MOCK_SERVER_START_FAIL: number;
    CORE_PANIC: number;
    ADDRESS_NOT_VALID: number;
    TLS_CONFIG: number;
};
export declare enum VERIFY_PROVIDER_RESPONSE {
    VERIFICATION_SUCCESSFUL = 0,
    VERIFICATION_FAILED = 1,
    NULL_POINTER_RECEIVED = 2,
    METHOD_PANICKED = 3,
    INVALID_ARGUMENTS = 4
}
export declare enum FfiFunctionResult {
    RESULT_OK = 0,
    RESULT_FAILED = 1
}
export declare enum FfiLogLevelFilter {
    LOG_LEVEL_OFF = 0,
    LOG_LEVEL_ERROR = 1,
    LOG_LEVEL_WARN = 2,
    LOG_LEVEL_INFO = 3,
    LOG_LEVEL_DEBUG = 4,
    LOG_LEVEL_TRACE = 5
}
export declare type Ffi = {
    pactffiInit(logLevel: string): string;
    pactffiVersion(): string;
    pactffiVerify(args: string, callback: (e: Error, res: number) => void): number;
    pactffiCreateMockServerForPact(handle: FfiPactHandle, address: string, tls: boolean): number;
    pactffiNewPact(consumer: string, provider: string): FfiPactHandle;
    pactffiWithSpecification(handle: FfiPactHandle, specification: FfiSpecificationVersion): boolean;
    pactffiWithPactMetadata(handle: FfiPactHandle, namespace_: string, name: string, value: string): boolean;
    pactffiNewInteraction(handle: FfiPactHandle, description: string): FfiInteractionHandle;
    pactffiUponReceiving(handle: FfiInteractionHandle, description: string): boolean;
    pactffiGiven(handle: FfiInteractionHandle, providerState: string): boolean;
    pactffiGivenWithParam(handle: FfiInteractionHandle, description: string, name: string, value: string): boolean;
    pactffiWithRequest(handle: FfiInteractionHandle, method: string, path: string): boolean;
    pactffiWithQueryParameter(handle: FfiInteractionHandle, name: string, index: number, value: string): boolean;
    pactffiWithHeader(handle: FfiInteractionHandle, part: FfiInteractionPart, name: string, index: number, value: string): boolean;
    pactffiWithBody(handle: FfiInteractionHandle, part: FfiInteractionPart, contentType: string, body: string): boolean;
    pactffiWithBinaryFile(handle: FfiInteractionHandle, part: FfiInteractionPart, contentType: string, body: Buffer, size: number): boolean;
    pactffiWithMultipartFile(handle: FfiInteractionHandle, part: FfiInteractionPart, contentType: string, file: string, partName: string): void;
    pactffiResponseStatus(handle: FfiInteractionHandle, status: number): boolean;
    pactffiWritePactFile(port: number, dir: string, overwrite: boolean): number;
    pactffiCleanupMockServer(port: number): boolean;
    pactffiMockServerMatched(port: number): boolean;
    pactffiMockServerMismatches(port: number): string;
    pactffiGetTlsCaCertificate(): string;
    pactffiLogMessage(source: string, logLevel: string, message: string): void;
    pactffiLogToBuffer(level: FfiLogLevelFilter): number;
    pactffiInitWithLogLevel(level: string): void;
    pactffiLogToStdout(level: FfiLogLevelFilter): number;
    pactffiLogToFile(fileName: string, level: FfiLogLevelFilter): number;
    pactffiFetchLogBuffer(logId: number): string;
};
