"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verify = void 0;
var logger_1 = require("../logger");
var argumentMapper_1 = require("./argumentMapper");
var ffi_1 = require("../ffi");
var types_1 = require("../ffi/types");
var verify = function (opts) {
    var ffi = ffi_1.getFfiLib(opts.logLevel);
    if (opts.logLevel) {
        logger_1.setLogLevel(opts.logLevel);
    }
    return new Promise(function (resolve, reject) {
        var request = argumentMapper_1.argumentMapper(opts)
            .map(function (s) { return s.replace('\n', ''); })
            .join('\n');
        logger_1.default.debug('sending arguments to FFI:');
        logger_1.default.debug(request);
        ffi.pactffiVerify(request, function (err, res) {
            logger_1.default.debug("response from verifier: " + err + ", " + res);
            if (err) {
                if (typeof err === 'string') {
                    logger_1.default.error(err);
                }
                else if (err.message) {
                    logger_1.default.error(err.message);
                }
                logger_1.default.pactCrash('The underlying pact core returned an error through the ffi interface');
                reject(err);
            }
            else {
                switch (res) {
                    case types_1.VERIFY_PROVIDER_RESPONSE.VERIFICATION_SUCCESSFUL:
                        logger_1.default.info('Verification successful');
                        resolve("finished: " + res);
                        break;
                    case types_1.VERIFY_PROVIDER_RESPONSE.VERIFICATION_FAILED:
                        logger_1.default.error('Verification unsuccessful');
                        reject(new Error('Verfication failed'));
                        break;
                    case types_1.VERIFY_PROVIDER_RESPONSE.INVALID_ARGUMENTS:
                        logger_1.default.pactCrash('The underlying pact core was invoked incorrectly.');
                        reject(new Error('Verification was unable to run'));
                        break;
                    default:
                        logger_1.default.pactCrash('The underlying pact core crashed in an unexpected way.');
                        reject(new Error('Pact core crashed'));
                        break;
                }
            }
        });
    });
};
exports.verify = verify;
//# sourceMappingURL=nativeVerifier.js.map